==> zio-aws-databasemigration_2.13-5.17.123.2-sources.jar: zio/aws/databasemigration/model/CreateEventSubscriptionResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateEventSubscriptionResponse(
    eventSubscription: Option[
      zio.aws.databasemigration.model.EventSubscription
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse = {
    import CreateEventSubscriptionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
      .builder()
      .optionallyWith(eventSubscription.map(value => value.buildAwsValue()))(
        _.eventSubscription
      )
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.CreateEventSubscriptionResponse.ReadOnly =
    zio.aws.databasemigration.model.CreateEventSubscriptionResponse
      .wrap(buildAwsValue())
}
object CreateEventSubscriptionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.CreateEventSubscriptionResponse =
      zio.aws.databasemigration.model.CreateEventSubscriptionResponse(
        eventSubscription.map(value => value.asEditable)
      )
    def eventSubscription
        : Option[zio.aws.databasemigration.model.EventSubscription.ReadOnly]
    def getEventSubscription: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.EventSubscription.ReadOnly
    ] = AwsError.unwrapOptionField("eventSubscription", eventSubscription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
  ) extends zio.aws.databasemigration.model.CreateEventSubscriptionResponse.ReadOnly {
    override val eventSubscription
        : Option[zio.aws.databasemigration.model.EventSubscription.ReadOnly] =
      scala
        .Option(impl.eventSubscription())
        .map(value =>
          zio.aws.databasemigration.model.EventSubscription.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
  ): zio.aws.databasemigration.model.CreateEventSubscriptionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_2.13-5.17.295.15-sources.jar: zio/aws/databasemigration/model/CreateEventSubscriptionResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateEventSubscriptionResponse(
    eventSubscription: Optional[
      zio.aws.databasemigration.model.EventSubscription
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse = {
    import CreateEventSubscriptionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
      .builder()
      .optionallyWith(eventSubscription.map(value => value.buildAwsValue()))(
        _.eventSubscription
      )
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.CreateEventSubscriptionResponse.ReadOnly =
    zio.aws.databasemigration.model.CreateEventSubscriptionResponse
      .wrap(buildAwsValue())
}
object CreateEventSubscriptionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.CreateEventSubscriptionResponse =
      zio.aws.databasemigration.model.CreateEventSubscriptionResponse(
        eventSubscription.map(value => value.asEditable)
      )
    def eventSubscription
        : Optional[zio.aws.databasemigration.model.EventSubscription.ReadOnly]
    def getEventSubscription: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.EventSubscription.ReadOnly
    ] = AwsError.unwrapOptionField("eventSubscription", eventSubscription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
  ) extends zio.aws.databasemigration.model.CreateEventSubscriptionResponse.ReadOnly {
    override val eventSubscription
        : Optional[zio.aws.databasemigration.model.EventSubscription.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.eventSubscription())
        .map(value =>
          zio.aws.databasemigration.model.EventSubscription.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.CreateEventSubscriptionResponse
  ): zio.aws.databasemigration.model.CreateEventSubscriptionResponse.ReadOnly =
    new Wrapper(impl)
}
